==> xiaoerke-common-1.0.127-sources.jar: com/cxqm/xiaoerke/modules/sys/entity/WechatUserInfo.java <==
package com.cxqm.xiaoerke.modules.sys.entity;

import net.sf.json.JSONArray;

import java.lang.reflect.Array;

/**
 * Created by sunzb on 16/12/23.
 */
public class WechatUserInfo {

	private String openid;
	private String nickname;
	private Integer sex;
	private String language;
	private String city;
	private String province;
	private String country;
	private String headimgurl;
	private String[] privilege;
	private String unionid;
	private Integer subscribe;


	public String getOpenid() {
		return openid;
	}

	public void setOpenid(String openid) {
		this.openid = openid;
	}

	public String getNickname() {
		return nickname;
	}

	public void setNickname(String nickname) {
		this.nickname = nickname;
	}

	public String getHeadimgurl() {
		return headimgurl;
	}

	public void setHeadimgurl(String headimgurl) {
		this.headimgurl = headimgurl;
	}

	public Integer getSex() {
		return sex;
	}

	public void setSex(Integer sex) {
		if(sex==null){
			this.sex = 0;
		}else{
			this.sex = Integer.valueOf(sex.toString());
		}
	}

	public String getLanguage() {
		return language;
	}

	public void setLanguage(String language) {
		this.language = language;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCountry() {
		return country;
	}

	public void setCountry(String country) {
		this.country = country;
	}

	public String[] getPrivilege() {
		return privilege;
	}

	public void setPrivilege(String[] privilege) {
		this.privilege = privilege;
	}

	public String getUnionid() {
		return unionid;
	}

	public void setUnionid(String unionid) {
		this.unionid = unionid;
	}

	public Integer getSubscribe() {
		return subscribe;
	}

	public void setSubscribe(Integer subscribe) {
		this.subscribe = subscribe;
	}
}

==> xiaoerke-common-1.1.8-sources.jar: com/cxqm/xiaoerke/modules/sys/entity/WechatUserInfo.java <==
package com.cxqm.xiaoerke.modules.sys.entity;

import net.sf.json.JSONArray;

import java.lang.reflect.Array;
import java.util.Date;

/**
 * Created by sunzb on 16/12/23.
 */
public class WechatUserInfo {

	private String openid;
	private String nickname;
	private Integer sex;
	private String language;
	private String city;
	private String province;
	private String country;
	private String headimgurl;
	private String[] privilege;
	private String unionid;
	private Integer subscribe;

	private Long getInfoTime;

	public Long getGetInfoTime() {
		return getInfoTime;
	}

	public void setGetInfoTime(Long getInfoTime) {
		this.getInfoTime = getInfoTime;
	}

	public String getOpenid() {
		return openid;
	}

	public void setOpenid(String openid) {
		this.openid = openid;
	}

	public String getNickname() {
		return nickname;
	}

	public void setNickname(String nickname) {
		this.nickname = nickname;
	}

	public String getHeadimgurl() {
		return headimgurl;
	}

	public void setHeadimgurl(String headimgurl) {
		this.headimgurl = headimgurl;
	}

	public Integer getSex() {
		return sex;
	}

	public void setSex(Integer sex) {
		if(sex==null){
			this.sex = 0;
		}else{
			this.sex = Integer.valueOf(sex.toString());
		}
	}

	public String getLanguage() {
		return language;
	}

	public void setLanguage(String language) {
		this.language = language;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCountry() {
		return country;
	}

	public void setCountry(String country) {
		this.country = country;
	}

	public String[] getPrivilege() {
		return privilege;
	}

	public void setPrivilege(String[] privilege) {
		this.privilege = privilege;
	}

	public String getUnionid() {
		return unionid;
	}

	public void setUnionid(String unionid) {
		this.unionid = unionid;
	}

	public Integer getSubscribe() {
		return subscribe;
	}

	public void setSubscribe(Integer subscribe) {
		this.subscribe = subscribe;
	}
}
